@@ -1,8 +1,9 @@
-# Copyright 2001-2004 The Apache Software Foundation
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
+# Licensed to the Apache Software Foundation (ASF) under one or more
+# contributor license agreements.  See the NOTICE file distributed with
+# this work for additional information regarding copyright ownership.
+# The ASF licenses this file to You under the Apache License, Version 2.0
+# (the "License"); you may not use this file except in compliance with
+# the License.  You may obtain a copy of the License at
 #
 #     http://www.apache.org/licenses/LICENSE-2.0
 #
@@ -21,15 +22,27 @@ use Exporter ();
 use Config;
 use Apache::TestConfig ();
 
+BEGIN {
+    # Apache::Test loads a bunch of mp2 stuff while getting itself
+    # together.  because we need to choose one of mp1 or mp2 to load
+    # check first (and we choose mp2) $mod_perl::VERSION == 2.0
+    # just because someone loaded Apache::Test.  This Is Bad.  so,
+    # let's try to correct for that here by removing mod_perl from
+    # %INC after the above use() statements settle in.  nobody
+    # should be relying on us loading up mod_perl.pm anyway...
+
+    delete $INC{'mod_perl.pm'};
+}
+
 use vars qw(@ISA @EXPORT %EXPORT_TAGS $VERSION %SubTests @SkipReasons);
 
-$VERSION = '1.25';
+$VERSION = '1.31';
 
 my @need = qw(need_lwp need_http11 need_cgi need_access need_auth
               need_module need_apache need_min_apache_version
               need_apache_version need_perl need_min_perl_version
               need_min_module_version need_threads need_apache_mpm
-              need_php need_php4 need_ssl);
+              need_php need_php4 need_ssl need_imagemap);
 
 my @have = map { (my $need = $_) =~ s/need/have/; $need } @need;
 
@@ -60,9 +73,9 @@ sub import {
     if (($_[0] and $_[0] =~ m/^-withtestmore/) || @testmore) {
         # special hoops for Test::More support
 
-        $real_plan = eval { 
+        $real_plan = eval {
 
-            require Test::More; 
+            require Test::More;
 
             no warnings qw(numeric);
             Test::Builder->VERSION('0.18_01');
@@ -132,17 +145,19 @@ EOE
 #so Perl's Test.pm can be run inside mod_perl
 sub test_pm_refresh {
     if (@testmore) {
-        Test::Builder->reset;
+        my $builder = Test::Builder->new;
 
-        Test::Builder->output(\*STDOUT);
-        Test::Builder->todo_output(\*STDOUT);
+        $builder->reset;
 
-        # this is STDOUT because Test::More seems to put 
+        $builder->output(\*STDOUT);
+        $builder->todo_output(\*STDOUT);
+
+        # this is STDOUT because Test::More seems to put
         # most of the stuff we want on STDERR, so it ends
         # up in the error_log instead of where the user can
         # see it.   consider leaving it alone based on
         # later user reports.
-        Test::Builder->failure_output(\*STDOUT);
+        $builder->failure_output(\*STDOUT);
     }
     else {
         $Test::TESTOUT = \*STDOUT;
@@ -287,11 +302,17 @@ sub need_module {
             }
         }
         die "bogus module name $_" unless /^[\w:.]+$/;
-        eval "require $_";
-        #print $@ if $@;
-        if ($@) {
-            push @reasons, "cannot find module '$_'";
+
+        # if the module was explicitly passed with a .c extension,
+        # do not try to eval it as a Perl module
+        my $not_found = 1;
+        unless (/\.c$/) {
+            eval "require $_";
+            $not_found = 0 unless $@;
+            #print $@ if $@;
         }
+        push @reasons, "cannot find module '$_'" if $not_found;
+
     }
     if (@reasons) {
         push @SkipReasons, @reasons;
@@ -327,23 +348,49 @@ sub need_min_module_version {
 }
 
 sub need_cgi {
-    need_module('cgi') || need_module('cgid');
+    return _need_multi(qw(cgi cgid));
 }
 
 sub need_php {
-    need_module('php4') || need_module('php5') || need_module('sapi_apache2.c');
+    return _need_multi(qw(php4 php5 sapi_apache2.c));
 }
 
 sub need_php4 {
-    need_module('php4') || need_module('sapi_apache2.c');
+    return _need_multi(qw(php4 sapi_apache2.c));
 }
 
 sub need_access {
-    need_module('access') || need_module('authz_host');
+    return _need_multi(qw(access authz_host));
 }
 
 sub need_auth {
-    need_module('auth') || need_module('auth_basic');
+    return _need_multi(qw(auth auth_basic));
+}
+
+sub need_imagemap {
+    return need_module("imagemap") || need_module("imap");
+}
+
+sub _need_multi {
+
+    my @check = @_;
+
+    my $rc = 0;
+
+    {
+        local @SkipReasons;
+
+        foreach my $module (@check) {
+          $rc ||= need_module($module);
+        }
+    }
+
+    my $reason = join ' or ', @check;
+
+    push @SkipReasons, "cannot find one of $reason"
+        unless $rc;
+
+    return $rc;
 }
 
 sub need_apache {
@@ -453,10 +500,13 @@ sub need_threads {
 
     # check APR support
     my $build_config = Apache::TestConfig->modperl_build_config;
-    my $apr_config = $build_config->get_apr_config();
-    unless ($apr_config->{HAS_THREADS}) {
-        $status = 0;
-        push @SkipReasons, "Apache/APR was built without threads support";
+
+    if ($build_config) {
+        my $apr_config = $build_config->get_apr_config();
+        unless ($apr_config->{HAS_THREADS}) {
+            $status = 0;
+            push @SkipReasons, "Apache/APR was built without threads support";
+        }
     }
 
     # check Perl's useithreads
@@ -586,7 +636,7 @@ But this won't hint the reason for skipping therefore it's better to
 use need():
 
   plan tests => 5,
-      need 'LWP', 
+      need 'LWP',
            { "not Win32" => sub { $^O eq 'MSWin32'} };
 
 see C<need()> for more info.
@@ -597,6 +647,12 @@ need_module() is called for each value in this array. The test is
 skipped if need_module() returns false (which happens when at least
 one C or Perl module from the list cannot be found).
 
+Watch out for case insensitive file systems or duplicate modules
+with the same name.  I.E.  If you mean mod_env.c
+   need_module('mod_env.c')
+Not
+   need_module('env')
+
 =item * a C<CODE> reference
 
 the tests will be skipped if the function returns a false value. For
@@ -648,7 +704,7 @@ with C<plan()> to decide whether a test will run, but C<have_apache()>
 within test logic to adjust expectations based on older or newer
 server versions.
 
-=over 
+=over
 
 =item need_http11
 
@@ -688,6 +744,12 @@ Requires a PHP module to be installed (version 4 or 5).
 
 Requires a PHP version 4 module to be installed.
 
+=item need_imagemap
+
+  plan tests => 5, need_imagemap;
+
+Requires a mod_imagemap or mod_imap be installed
+
 =item need_apache
 
   plan tests => 5, need_apache 2;
@@ -800,7 +862,7 @@ Currently works only for perl modules.
 
   plan tests => 5,
       need 'LWP',
-           { "perl >= 5.8.0 and w/ithreads is required" => 
+           { "perl >= 5.8.0 and w/ithreads is required" =>
              ($Config{useperlio} && $] >= 5.008) },
            { "not Win32"                 => sub { $^O eq 'MSWin32' },
              "foo is disabled"           => \&is_foo_enabled,
@@ -908,11 +970,11 @@ are returned.
 
 =head1 Test::More Integration
 
-There are a few caveats if you want to use I<Apache::Test> with 
+There are a few caveats if you want to use I<Apache::Test> with
 I<Test::More> instead of the default I<Test> backend.  The first is
 that I<Test::More> requires you to use its own C<plan()> function
 and not the one that ships with I<Apache::Test>.  I<Test::More> also
-defines C<ok()> and C<skip()> functions that are different, and 
+defines C<ok()> and C<skip()> functions that are different, and
 simply C<use>ing both modules in your test script will lead to redefined
 warnings for these subroutines.
 
@@ -928,7 +990,7 @@ with I<Test::More>.
 
     ok ('yes', 'testing ok');  # Test::More::ok()
 
-Now, while this works fine for standard client-side tests 
+Now, while this works fine for standard client-side tests
 (such as C<t/basic.t>), the more advanced features of I<Apache::Test>
 require using I<Test::More> as the sole driver behind the scenes.
 
@@ -952,7 +1014,7 @@ C<-withtestmore> tells I<Apache::Test> to use I<Test::More>
 instead of I<Test.pm> behind the scenes.  Note that you are not
 required to C<use Test::More> yourself with the C<-withtestmore>
 option and that the C<use Test::More tests =E<gt> 1> syntax
-may have unexpected results.  
+may have unexpected results.
 
 Note that I<Test::More> version 0.49, available within the
 I<Test::Simple> 0.49 distribution on CPAN, or greater is required
