@@ -1,8 +1,9 @@
-# Copyright 2001-2004 The Apache Software Foundation
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
+# Licensed to the Apache Software Foundation (ASF) under one or more
+# contributor license agreements.  See the NOTICE file distributed with
+# this work for additional information regarding copyright ownership.
+# The ASF licenses this file to You under the Apache License, Version 2.0
+# (the "License"); you may not use this file except in compliance with
+# the License.  You may obtain a copy of the License at
 #
 #     http://www.apache.org/licenses/LICENSE-2.0
 #
@@ -22,7 +23,7 @@ use constant OSX     => $^O eq 'darwin';
 use constant CYGWIN  => $^O eq 'cygwin';
 use constant NETWARE => $^O eq 'NetWare';
 use constant SOLARIS => $^O eq 'solaris';
-use constant WINFU   => WIN32 || CYGWIN || NETWARE;
+use constant WINFU   => WIN32 || NETWARE;
 use constant COLOR   => ($ENV{APACHE_TEST_COLOR} && -t STDOUT) ? 1 : 0;
 
 use constant DEFAULT_PORT => 8529;
@@ -74,6 +75,7 @@ my %vars_to_env = (
    t_dir           => 'the t/ test directory (default is $top_dir/t)',
    t_conf          => 'the conf/ test directory (default is $t_dir/conf)',
    t_logs          => 'the logs/ test directory (default is $t_dir/logs)',
+   t_pid_file      => 'location of the pid file (default is $t_logs/httpd.pid)',
    t_conf_file     => 'test httpd.conf file (default is $t_conf/httpd.conf)',
    src_dir         => 'source directory to look for mod_foos.so',
    serverroot      => 'ServerRoot (default is $t_dir)',
@@ -102,7 +104,7 @@ my %vars_to_env = (
 );
 
 my %filepath_conf_opts = map { $_ => 1 }
-    qw(top_dir t_dir t_conf t_logs t_conf_file src_dir serverroot
+    qw(top_dir t_dir t_conf t_logs t_pid_file t_conf_file src_dir serverroot
        documentroot bindir sbindir httpd apxs httpd_conf httpd_conf_extra
        perlpod sslca libmodperl);
 
@@ -174,14 +176,28 @@ sub server { shift->{server} }
 
 sub modperl_build_config {
 
+    my $self = shift;
+
+    my $server = ref $self ? $self->server : new_test_server();
+
     # we don't want to get mp2 preconfigured data in order to be able
     # to get the interactive tests running.
     return undef if $ENV{APACHE_TEST_INTERACTIVE_CONFIG_TEST};
 
-    eval {
-        require Apache2::Build;
-    } or return undef;
-    return Apache2::Build->build_config;
+    # we can't do this if we're using httpd 1.3.X
+    # even if mod_perl2 is installed on the box
+    # similarly, we shouldn't be loading mp2 if we're not
+    # absolutely certain we're in a 2.X environment yet
+    # (such as mod_perl's own build or runtime environment)
+    if (($server->{rev} && $server->{rev} == 2) ||
+        IS_MOD_PERL_2_BUILD || $ENV{MOD_PERL_API_VERSION}) {
+        eval {
+            require Apache2::Build;
+        } or return;
+        return Apache2::Build->build_config;
+    }
+
+    return;
 }
 
 sub new_test_server {
@@ -293,6 +309,7 @@ sub new {
     $vars->{sslcaorg}     ||= 'asf';
     $vars->{t_logs}       ||= catfile $vars->{serverroot}, 'logs';
     $vars->{t_conf_file}  ||= catfile $vars->{t_conf},   'httpd.conf';
+    $vars->{t_pid_file}   ||= catfile $vars->{t_logs},   'httpd.pid';
 
     if (WINFU) {
         for (keys %$vars) {
@@ -357,7 +374,7 @@ sub httpd_config {
         # continue because the interactive config can't work with
         # mod_perl 2.0 build (by design)
         if (IS_MOD_PERL_2_BUILD){
-            my $mp2_build = modperl_build_config();
+            my $mp2_build = $self->modperl_build_config();
             # if mod_perl 2 was built against the httpd source it
             # doesn't know where to find apxs/httpd, so in this case
             # fall back to interactive config
@@ -682,7 +699,7 @@ sub default_apxs {
 
     return $self->{vars}->{apxs} if $self->{vars}->{apxs};
 
-    if (my $build_config = modperl_build_config()) {
+    if (my $build_config = $self->modperl_build_config()) {
         return $build_config->{MP_APXS};
     }
 
@@ -690,13 +707,24 @@ sub default_apxs {
 }
 
 sub default_httpd {
-    my $vars = shift->{vars};
+    my $self = shift;
 
-    if (my $build_config = modperl_build_config()) {
+    my $vars = $self->{vars};
+
+    if (my $build_config = $self->modperl_build_config()) {
         if (my $p = $build_config->{MP_AP_PREFIX}) {
             for my $bindir (qw(bin sbin)) {
                 my $httpd = catfile $p, $bindir, $vars->{target};
                 return $httpd if -e $httpd;
+                # The executable on Win32 in Apache/2.2 is httpd.exe,
+                # so try that if Apache.exe doesn't exist
+                if (WIN32) {
+                    $httpd = catfile $p, $bindir, 'httpd.EXE';
+                    if (-e $httpd) {
+                        $vars->{target} = 'httpd.EXE';
+                        return $httpd;
+                    }
+                }
             }
         }
     }
@@ -733,7 +761,7 @@ my $port_memoized;
 sub select_first_port {
     my $self = shift;
 
-    my $port ||= $port_memoized || $ENV{APACHE_TEST_PORT} 
+    my $port ||= $port_memoized || $ENV{APACHE_TEST_PORT}
         || $self->{vars}{port} || DEFAULT_PORT;
 
     # memoize
@@ -842,12 +870,14 @@ sub find_apache_module {
 my %warn_style = (
     html    => sub { "<!-- @_ -->" },
     c       => sub { "/* @_ */" },
+    php     => sub { "<?php /* \n@_ \n*/ ?>" },
     default => sub { join '', grep {s/^/\# /gm} @_ },
 );
 
 my %file_ext = (
     map({$_ => 'html'} qw(htm html)),
     map({$_ => 'c'   } qw(c h)),
+    map({$_ => 'php' } qw(php)),
 );
 
 # return the passed file's extension or '' if there is no one
@@ -869,9 +899,11 @@ sub warn_style_sub_ref {
 sub genwarning {
     my($self, $filename, $from_filename) = @_;
     return unless $filename;
+    my $time = scalar localtime;
     my $warning = "WARNING: this file is generated";
     $warning .= " (from $from_filename)" if defined $from_filename;
     $warning .= ", do not edit\n";
+    $warning .= "generated on $time\n";
     $warning .= calls_trace();
     return $self->warn_style_sub_ref($filename)->($warning);
 }
@@ -1007,8 +1039,8 @@ sub write_perlscript {
 
     my $fh = $self->genfile($file, undef, 1);
 
-    # shebang
-    print $fh "#!$Config{perlpath}\n";
+    my $shebang = make_shebang();
+    print $fh $shebang;
 
     $self->genfile_warning($file, undef, $fh);
 
@@ -1018,6 +1050,23 @@ sub write_perlscript {
     chmod 0755, $file;
 }
 
+sub make_shebang {
+    # if perlpath is longer than 62 chars, some shells on certain
+    # platforms won't be able to run the shebang line, so when seeing
+    # a long perlpath use the eval workaround.
+    # see: http://en.wikipedia.org/wiki/Shebang
+    # http://homepages.cwi.nl/~aeb/std/shebang/
+    my $shebang = length $Config{perlpath} < 62
+        ? "#!$Config{perlpath}\n"
+        : <<EOI;
+$Config{'startperl'}
+    eval 'exec $Config{perlpath} -S \$0 \${1+"\$@"}'
+        if \$running_under_some_shell;
+EOI
+
+    return $shebang;
+}
+
 sub cpfile {
     my($self, $from, $to) = @_;
     File::Copy::copy($from, $to);
@@ -1094,6 +1143,10 @@ sub clean {
     }
 }
 
+my %special_tokens = (
+    nextavailableport => sub { shift->server->select_next_port }
+);
+
 sub replace {
     my $self = shift;
     my $file = $Apache::TestConfig::File
@@ -1101,9 +1154,15 @@ sub replace {
 
     s[@(\w+)@]
      [ my $key = lc $1;
-      exists $self->{vars}->{$key}
-      ? $self->{vars}->{$key}
-      : die "invalid token: \@$1\@ $file\n";
+       if (my $callback = $special_tokens{$key}) {
+           $self->$callback;
+       }
+       elsif (exists $self->{vars}->{$key}) {
+           $self->{vars}->{$key};
+       }
+       else {
+           die "invalid token: \@$1\@ $file\n";
+       }
      ]ge;
 }
 
@@ -1180,6 +1239,8 @@ sub parse_vhost {
         }
     }
 
+    $self->{vars}->{$module . '_port'} = $port;
+
     #there are two ways of building a vhost
     #first is when we parse test .pm and .c files
     #second is when we scan *.conf.in
@@ -1339,7 +1400,7 @@ sub extra_conf_files_needing_update {
     finddepth(sub {
         return unless /\.in$/;
         (my $generated = $File::Find::name) =~ s/\.in$//;
-        push @need_update, $generated 
+        push @need_update, $generated
             unless -e $generated && -M $generated < -M $File::Find::name;
     }, $self->{vars}->{t_conf});
 
@@ -1530,9 +1591,9 @@ sub generate_httpd_conf {
 
     $self->preamble_run($out);
 
-    for my $name (qw(user group)) { #win32/cygwin do not support
+    for my $name (qw(user group)) { #win32
         if ($vars->{$name}) {
-            print $out "\u$name    $vars->{$name}\n";
+            print $out qq[\u$name    "$vars->{$name}"\n];
         }
     }
 
@@ -1584,7 +1645,7 @@ sub need_reconfiguration {
     # if httpd.conf is older than executable
     push @reasons,
         "$exe is newer than $vars->{t_conf_file}"
-            if -e $exe && 
+            if -e $exe &&
                -e $vars->{t_conf_file} &&
                -M $exe < -M $vars->{t_conf_file};
 
@@ -1608,6 +1669,17 @@ sub need_reconfiguration {
         }
     }
 
+    # if the generated config was created with a version of Apache-Test
+    # less than the current version
+    {
+      my $current = Apache::Test->VERSION;
+      my $config  = $self->{apache_test_version};
+
+      if (! $config || $config < $current) {
+          push @reasons, "configuration generated with old Apache-Test";
+      }
+    }
+
     return @reasons;
 }
 
@@ -1694,14 +1766,15 @@ sub apxs {
     $self->{_apxs}{$q};
 }
 
-# Temporarily untaint PATH
+# return an untainted PATH
 sub untaint_path {
     my $path = shift;
     ($path) = ( $path =~ /(.*)/ );
     # win32 uses ';' for a path separator, assume others use ':'
     my $sep = WIN32 ? ';' : ':';
     # -T disallows relative and empty directories in the PATH
-    return join $sep, grep !/^(\.|$)/, split /$sep/, $path;
+    return join $sep, grep File::Spec->file_name_is_absolute($_),
+        grep length($_), split /$sep/, $path;
 }
 
 sub pop_dir {
@@ -1728,12 +1801,15 @@ sub add_inc {
     my $apache_test_dir = catdir $top_dir, "Apache-Test";
     unshift @dirs, $apache_test_dir if -d $apache_test_dir;
 
+    lib::->import(@dirs);
+
     if ($ENV{APACHE_TEST_LIVE_DEV}) {
+        # add lib/ in a separate call to ensure that it'll end up on
+        # top of @INC
         my $lib_dir = catdir $top_dir, "lib";
-        push @dirs, $lib_dir if -d $lib_dir;
+        lib::->import($lib_dir) if -d $lib_dir;
     }
 
-    lib::->import(@dirs);
     #print join "\n", "add_inc", @INC, "";
 }
 
@@ -1785,6 +1861,9 @@ sub save {
 
     return unless $self->{save};
 
+    # add in the Apache-Test version for later comparisions
+    $self->{apache_test_version} = Apache::Test->VERSION;
+
     my $name = 'apache_test_config';
     my $file = catfile $self->{vars}->{t_conf}, "$name.pm";
     my $fh = $self->genfile($file);
@@ -1818,7 +1897,10 @@ sub as_string {
         $command = "$httpd -V";
         $cfg .= "\n*** $command\n";
         $cfg .= qx{$command};
-    } else {
+
+        $cfg .= ldd_as_string($httpd);
+    }
+    else {
         $cfg .= "\n\n*** The httpd binary was not found\n";
     }
 
@@ -1831,6 +1913,28 @@ sub as_string {
     return $cfg;
 }
 
+sub ldd_as_string {
+    my $httpd = shift;
+
+    my $command;
+    if (OSX) {
+        my $otool = which('otool');
+        $command = "$otool -L $httpd" if $otool;
+    }
+    elsif (!WIN32) {
+        my $ldd = which('ldd');
+        $command = "$ldd $httpd" if $ldd;
+    }
+
+    my $cfg = '';
+    if ($command) {
+        $cfg .= "\n*** $command\n";
+        $cfg .= qx{$command};
+    }
+
+    return $cfg;
+}
+
 # make a string suitable for feed to shell calls (wrap in quotes and
 # escape quotes)
 sub shell_ready {
@@ -2109,7 +2213,7 @@ EOC
 sub custom_config_add_conf_opts {
     my $args = shift;
 
-    return unless $Apache::TestConfigData::vars and 
+    return unless $Apache::TestConfigData::vars and
         keys %$Apache::TestConfigData::vars;
 
     debug "overlaying custom config data";
@@ -2226,7 +2330,7 @@ If for some reason you want to skip the test suite, type: skip
         }
         my $optional = 0;
         my $wanted = 'httpd';
-        $vars->{$wanted} = 
+        $vars->{$wanted} =
             _custom_config_prompt_path($wanted, \%choices, $optional);
     }
 
@@ -2265,7 +2369,7 @@ or via the environment variable APACHE_TEST_APXS. For example:
         }
         my $optional = 1;
         my $wanted = 'apxs';
-        $vars->{$wanted} = 
+        $vars->{$wanted} =
             _custom_config_prompt_path($wanted, \%choices, $optional);
     }
 
@@ -2490,7 +2594,42 @@ a tty. But sometimes there is a program that can answer the prompts
 interactive config won't be skipped (if needed).
 
 
+=head1 Special Placeholders
 
+When generating configuration files from the I<*.in> templates,
+special placeholder variables get substituted. To embed a placeholder
+use the C<@foo@> syntax. For example in I<extra.conf.in> you can
+write:
+
+  Include @ServerRoot@/conf/myconfig.conf
+
+When I<extra.conf> is generated, C<@ServerRoot@> will get replaced
+with the location of the server root.
+
+Placeholders are case-insensitive.
+
+Available placeholders:
+
+=head2 Configuration Options
+
+All configuration variables that can be passed to C<t/TEST>, such as
+C<MaxClients>, C<DocumentRoot>, C<ServerRoot>, etc. To see the
+complete list run:
+
+  % t/TEST --help
+
+and you will find them in the C<configuration options> sections.
+
+=head2 NextAvailablePort
+
+Every time this placeholder is encountered it'll be replaced with the
+next available port. This is very useful if you need to allocate a
+special port, but not hardcode it. Later when running:
+
+  % t/TEST -port=select
+
+it's possible to run several concurrent test suites on the same
+machine, w/o having port collisions.
 
 =head1 AUTHOR
 
@@ -2507,7 +2646,7 @@ Listen     0.0.0.0:@Port@
 ServerRoot   "@ServerRoot@"
 DocumentRoot "@DocumentRoot@"
 
-PidFile     @t_logs@/httpd.pid
+PidFile     @t_pid_file@
 ErrorLog    @t_logs@/error_log
 LogLevel    debug
 
@@ -2515,6 +2654,10 @@ LogLevel    debug
     TransferLog @t_logs@/access_log
 </IfModule>
 
+<IfModule mod_cgid.c>
+    ScriptSock @t_logs@/cgisock
+</IfModule>
+
 ServerAdmin @ServerAdmin@
 
 #needed for http/1.1 testing
