@@ -1,8 +1,9 @@
-# Copyright 2001-2004 The Apache Software Foundation
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
+# Licensed to the Apache Software Foundation (ASF) under one or more
+# contributor license agreements.  See the NOTICE file distributed with
+# this work for additional information regarding copyright ownership.
+# The ASF licenses this file to You under the Apache License, Version 2.0
+# (the "License"); you may not use this file except in compliance with
+# the License.  You may obtain a copy of the License at
 #
 #     http://www.apache.org/licenses/LICENSE-2.0
 #
@@ -117,7 +118,10 @@ sub clean {
 
 sub pid_file {
     my $self = shift;
-    catfile $self->{config}->{vars}->{t_logs}, 'httpd.pid';
+
+    my $vars = $self->{config}->{vars};
+
+    return $vars->{t_pid_file} || catfile $vars->{t_logs}, 'httpd.pid';
 }
 
 sub dversion {
@@ -265,7 +269,8 @@ sub start_gdb {
         $command = qq{ddd --gdb --debugger "gdb -command $file" $httpd};
     }
     else {
-        $command = "gdb $httpd -command $file";
+        ## defaults to gdb if not set in %ENV or via -debug
+        $command = "$debugger $httpd -command $file";
     }
 
     $self->note_debugging;
@@ -296,14 +301,28 @@ sub start_debugger {
 
     $opts->{debugger} ||= $ENV{MP_DEBUGGER} || 'gdb';
 
-    unless ($debuggers{ $opts->{debugger} }) {
+    # XXX: FreeBSD 5.2+
+    #      gdb 6.1 and before segfaults when trying to
+    #      debug httpd startup code. 6.5 has been proven
+    #      to work.  FreeBSD typically installs this as
+    #      gdb65.
+    #      Is it worth it to check the debugger and os version
+    #      and die ?
+
+    unless (grep { /^$opts->{debugger}/ } keys %debuggers) {
         error "$opts->{debugger} is not a supported debugger",
               "These are the supported debuggers: ".
               join ", ", sort keys %debuggers;
         die("\n");
     }
 
-    my $method = "start_" . $debuggers{ $opts->{debugger} };
+    my $debugger = $opts->{debugger};
+    $debugger =~ s/\d+$//;
+
+    my $method = "start_" . $debuggers{$debugger};
+
+    ## $opts->{debugger} is passed through unchanged
+    ## so when we try to run it next, its found.
     $self->$method($opts);
 }
 
