@@ -1,8 +1,9 @@
-# Copyright 2001-2004 The Apache Software Foundation
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
+# Licensed to the Apache Software Foundation (ASF) under one or more
+# contributor license agreements.  See the NOTICE file distributed with
+# this work for additional information regarding copyright ownership.
+# The ASF licenses this file to You under the Apache License, Version 2.0
+# (the "License"); you may not use this file except in compliance with
+# the License.  You may obtain a copy of the License at
 #
 #     http://www.apache.org/licenses/LICENSE-2.0
 #
@@ -23,25 +24,27 @@ use Exporter ();
 use Carp ();
 use Config;
 use File::Basename qw(dirname);
-use File::Spec::Functions qw(catfile file_name_is_absolute);
+use File::Spec::Functions qw(catfile catdir file_name_is_absolute tmpdir);
 use Symbol ();
+use Fcntl qw(SEEK_END);
 
 use Apache::Test ();
 use Apache::TestConfig ();
 
 use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %CLEAN);
 
-$VERSION = '0.01';
+$VERSION = '0.02';
 @ISA     = qw(Exporter);
 
 @EXPORT = qw(t_cmp t_debug t_append_file t_write_file t_open_file
-    t_mkdir t_rmtree t_is_equal t_filepath_cmp
+    t_mkdir t_rmtree t_is_equal t_filepath_cmp t_write_test_lib
     t_server_log_error_is_expected t_server_log_warn_is_expected
     t_client_log_error_is_expected t_client_log_warn_is_expected
 );
 
 @EXPORT_OK = qw(t_write_perl_script t_write_shell_script t_chown
-               t_catfile_apache t_catfile);
+               t_catfile_apache t_catfile
+               t_start_error_log_watch t_finish_error_log_watch);
 
 %CLEAN = ();
 
@@ -51,6 +54,27 @@ $Apache::TestUtil::DEBUG_OUTPUT = \*STDOUT;
 use constant HAS_DUMPER => eval { $] >= 5.6 && require Data::Dumper; };
 use constant INDENT     => 4;
 
+{
+    my $f;
+    sub t_start_error_log_watch {
+
+        my $name = File::Spec->catfile(Apache::Test::vars->{t_logs}, 'error_log');
+        open $f, "$name" or die "ERROR: Cannot open $name: $!\n";
+        seek $f, 0, SEEK_END;
+
+        return;
+    }
+
+    sub t_finish_error_log_watch {
+
+        local $/ = "\n";
+        my @lines = <$f>;
+        undef $f;
+
+        return @lines;
+    }
+}
+
 # because of the prototype and recursive call to itself a forward
 # declaration is needed
 sub t_is_equal ($$);
@@ -108,7 +132,7 @@ sub t_is_equal ($$) {
 
 
 sub t_cmp ($$;$) {
-    Carp::carp(join(":", (caller)[1..2]) . 
+    Carp::carp(join(":", (caller)[1..2]) .
         ' usage: $res = t_cmp($received, $expected, [$comment])')
             if @_ < 2 || @_ > 3;
 
@@ -167,6 +191,18 @@ sub t_open_file {
     return $fh;
 }
 
+sub _temp_package_dir {
+    return catdir(tmpdir(), 'apache_test');
+}
+
+sub t_write_test_lib {
+    my $file = shift;
+
+    die "must pass a filename" unless defined $file;
+
+    t_write_file(catdir(_temp_package_dir(), $file), @_);
+}
+
 sub t_write_file {
     my $file = shift;
 
@@ -328,7 +364,7 @@ sub struct_as_string{
     }
 }
 
-my $banner_format = 
+my $banner_format =
     "\n*** The following %s expected and harmless ***\n";
 
 sub is_expected_banner {
@@ -523,6 +559,17 @@ circumstances unless running under verbose mode.
 
 This function is exported by default.
 
+=item t_write_test_lib()
+
+  t_write_test_lib($filename, @lines)
+
+t_write_test_lib() creates a new file at I<$filename> or overwrites
+the existing file with the content passed in I<@lines>.  The file
+is created in a temporary directory which is added to @INC at
+test configuration time.  It is intended to be used for creating
+temporary packages for testing which can be modified at run time,
+see the Apache::Reload unit tests for an example.
+
 =item t_write_file()
 
   t_write_file($filename, @lines);
@@ -720,9 +767,9 @@ For example the following client script fails to find the handler:
   use Apache::Test;
   use Apache::TestUtil;
   use Apache::TestRequest qw(GET);
-  
+
   plan tests => 1;
-  
+
   t_client_log_error_is_expected();
   my $url = "/error_document/cannot_be_found";
   my $res = GET($url);
@@ -732,7 +779,7 @@ After running this test the I<error_log> file will include an entry
 similar to the following snippet:
 
   *** The following error entry is expected and harmless ***
-  [Tue Apr 01 14:02:55 2003] [error] [client 127.0.0.1] 
+  [Tue Apr 01 14:02:55 2003] [error] [client 127.0.0.1]
   File does not exist: /tmp/test/t/htdocs/error
 
 When more than one entry is expected, an optional numerical argument,
@@ -772,6 +819,18 @@ It is useful when comparing something to that returned by Apache,
 which uses a Unix-style specification with forward slashes for
 directory separators. The function is not exported by default.
 
+=item t_start_error_log_watch(), t_finish_error_log_watch()
+
+This pair of functions provides an easy interface for checking
+the presence or absense of any particular message or messages
+in the httpd error_log that were generated by the httpd daemon
+as part of a test suite.  It is likely, that you should proceed
+this with a call to one of the t_*_is_expected() functions.
+
+  t_start_error_log_watch();
+  do_it;
+  ok grep {...} t_finish_error_log_watch()
+
 =back
 
 =head1 AUTHOR
