@@ -1,8 +1,9 @@
-# Copyright 2003-2005 The Apache Software Foundation
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
+# Licensed to the Apache Software Foundation (ASF) under one or more
+# contributor license agreements.  See the NOTICE file distributed with
+# this work for additional information regarding copyright ownership.
+# The ASF licenses this file to You under the Apache License, Version 2.0
+# (the "License"); you may not use this file except in compliance with
+# the License.  You may obtain a copy of the License at
 #
 #     http://www.apache.org/licenses/LICENSE-2.0
 #
@@ -28,7 +29,7 @@ use File::Spec ();
 
 use Apache2::Const -compile => qw(OK);
 
-$Apache2::Status::VERSION = '3.00'; # mod_perl 2.0
+$Apache2::Status::VERSION = '4.00'; # mod_perl 2.0
 
 use constant IS_WIN32 => ($^O eq "MSWin32");
 
@@ -42,14 +43,9 @@ my %status = (
     env       => "Environment",
     sig       => "Signal Handlers",
     myconfig  => "Perl Configuration",
-    hooks     => "Enabled mod_perl Hooks",
 );
-# XXX: is $status{hooks} supported with any mp2 version?
-# If not, why not just remove it from the above initialization?
-delete $status{'hooks'} if $mod_perl2::VERSION >= 1.9901;
 delete $status{'sig'} if IS_WIN32;
 
-# XXX: needs porting
 if ($Apache2::PerlSections::Save) {
     $status{"section_config"} = "Perl Section Configuration";
 }
@@ -62,19 +58,19 @@ my %requires = (
     b           => ["",                  "B",              0,    ],
     graph       => ["StatusGraph",       "B::Graph",       0.03, ],
     lexinfo     => ["StatusLexInfo",     "B::LexInfo",     0,    ],
-    xref        => ["",                  "B::Xref",        0,    ],
+    xref        => ["StatusXref",        "B::Xref",        1.01, ],
     terse       => ["StatusTerse",       "B::Terse",       0,    ],
-    tersesize   => ["StatusTerseSize",   "B::TerseSize",   0,    ],
-    packagesize => ["StatusPackageSize", "B::TerseSize",   0,    ],
-    peek        => ["StatusPeek",        "Apache2::Peek",   0,    ], # XXX: version?
+    tersesize   => ["StatusTerseSize",   "B::TerseSize",   0.09, ],
+    packagesize => ["StatusPackageSize", "B::TerseSize",   0.09, ],
+    peek        => ["StatusPeek",        "Apache::Peek",   1.03, ],
 );
 
 sub has {
-    my($r, $what) = @_;
+    my ($r, $what) = @_;
 
     return 0 unless exists $requires{$what};
 
-    my($opt, $module, $version) = @{ $requires{$what} };
+    my ($opt, $module, $version) = @{ $requires{$what} };
 
     (my $file = $module) =~ s|::|/|;
     $file .= ".pm";
@@ -98,13 +94,13 @@ sub install_hint {
 }
 
 sub status_config {
-    my($r, $key) = @_;
+    my ($r, $key) = @_;
     return (lc($r->dir_config($key)) eq "on") ||
         (lc($r->dir_config('StatusOptionsAll')) eq "on");
 }
 
 sub menu_item {
-    my($self, $key, $val, $sub) = @_;
+    my ($self, $key, $val, $sub) = @_;
     $status{$key} = $val;
     no strict;
     no warnings 'redefine';
@@ -112,7 +108,7 @@ sub menu_item {
 }
 
 sub handler {
-    my($r) = @_;
+    my ($r) = @_;
     my $qs = $r->args || "";
     my $sub = "status_$qs";
     no strict 'refs';
@@ -133,7 +129,7 @@ sub handler {
         my $uri = $r->uri;
         $r->print('<p>');
         $r->print(
-            map { qq[<a href="$uri?$_">$status{$_}</a><br>\n] } keys %status
+            map { qq[<a href="$uri?$_">$status{$_}</a><br />\n] } sort { lc $a cmp lc $b } keys %status
         );
         $r->print('</p>');
     }
@@ -149,34 +145,36 @@ sub header {
     $r->content_type("text/html");
     my $v = $^V ? sprintf "v%vd", $^V : $];
     $r->print(<<"EOF");
-<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01//EN">
-<html lang="en">
-<head>
-  <title>Apache2::Status</title>
-  <style type="text/css">
-  body {
-    color: #000;
-    background-color: #fff;
-  }
-  p.hdr {
-    background-color: #ddd;
-    border: 2px outset;
-    padding: 3px;
-    width: 99%;
-  }
-  </style>
-</head>
-<body>
-<p class="hdr">
-  Embedded Perl version <b>$v</b> for <b>$srv</b> process <b>$$</b>,<br>
-  running since $start
-</p>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
+"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
+
+<html lang="en" xmlns="http://www.w3.org/1999/xhtml">
+  <head>
+    <title>Apache2::Status $Apache2::Status::VERSION</title>
+    <style type="text/css">
+      body {
+        color: #000;
+        background-color: #fff;
+      }
+      p.hdr {
+        background-color: #ddd;
+        border: 2px outset;
+        padding: 3px;
+        width: 99%;
+     }
+   </style>
+  </head>
+  <body>
+    <p class="hdr">
+      Embedded Perl version <b>$v</b> for <b>$srv</b> process <b>$$</b>,<br />
+      running since $start
+    </p>
 EOF
 
 }
 
 sub symdump {
-    my($r, $package) = @_;
+    my ($r, $package) = @_;
 
     return install_hint("Devel::Symdump") unless has($r, "symdump");
 
@@ -187,39 +185,23 @@ sub symdump {
 }
 
 sub status_symdump {
-    my($r) = @_;
+    my ($r) = @_;
     [symdump($r, 'main')];
 }
 
 sub status_section_config {
-    my($r) = @_;
+    my ($r) = @_;
     require Apache2::PerlSections;
     ["<pre>", Apache2::PerlSections->dump, "</pre>"];
 }
 
-sub status_hooks {
-    my($r) = @_;
-    # XXX: hooks list access doesn't exist yet in 2.0
-    require mod_perl;
-    require mod_perl_hooks;
-    my @retval = qw(<table>);
-    my @list = mod_perl::hooks();
-    for my $hook (sort @list) {
-        my $on_off = 
-            mod_perl::hook($hook) ? "<b>Enabled</b>" : "<i>Disabled</i>";
-        push @retval, "<tr><td>$hook</td><td>$on_off</td></tr>\n";
-    }
-    push @retval, qw(</table>);
-    \@retval;
-}
-
 sub status_inc {
-    my($r) = @_;
+    my ($r) = @_;
 
     my $uri = $r->uri;
     my @retval = (
         '<table border="1">',
-        "<tr>", 
+        "<tr>",
         (map "<td><b>$_</b></td>", qw(Package Version Modified File)),
         "</tr>\n"
     );
@@ -233,22 +215,26 @@ sub status_inc {
         no strict 'refs';
         (my $module = $file) =~ s,/,::,g;
         $module =~ s,\.pm$,,;
+        next if $module eq 'mod_perl';
         my $v = ${"$module\:\:VERSION"} || '0.00';
+        my $mtime = -e $INC{$file} ? scalar localtime((stat $INC{$file})[9]) :
+            'N/A';
+
         push @retval, (
-            "<tr>", 
-            (map "<td>$_</td>", 
+            "<tr>",
+            (map "<td>$_</td>",
                 qq(<a href="$uri?$module">$module</a>),
-                $v, scalar localtime((stat $INC{$file})[9]), $INC{$file}),
+                $v, $mtime, $INC{$file}),
             "</tr>\n"
         );
     }
     push @retval, "</table>\n";
-    push @retval, "<p><b>\@INC</b> = <br>", join "<br>\n", @INC, "";
+    push @retval, "<p><b>\@INC</b> = <br />", join "<br />\n", @INC, "";
     \@retval;
 }
 
 sub status_script {
-    my($r) = @_;
+    my ($r) = @_;
 
     my @retval = (
         '<table border="1">',
@@ -257,7 +243,7 @@ sub status_script {
 
     foreach my $file (sort keys %INC) {
         next if $file =~ m:\.(pm|al|ix)$:;
-        push @retval, 
+        push @retval,
             qq(<tr><td>$file</td><td>$INC{$file}</td></tr>\n);
     }
     push @retval, "</table>";
@@ -267,7 +253,7 @@ sub status_script {
 my $RegistryCache;
 
 sub registry_cache {
-    my($self, $cache) = @_;
+    my ($self, $cache) = @_;
 
     # XXX: generalize
 
@@ -276,7 +262,7 @@ sub registry_cache {
 }
 
 sub get_packages_per_handler {
-    my($root, $stash) = @_;
+    my ($root, $stash) = @_;
 
     my %handlers = ();
     my @packages = get_packages($stash);
@@ -288,7 +274,7 @@ sub get_packages_per_handler {
 }
 
 sub get_packages {
-    my($stash) = @_;
+    my ($stash) = @_;
 
     no strict 'refs';
     my @packages = ();
@@ -300,7 +286,7 @@ sub get_packages {
 }
 
 sub status_rgysubs {
-    my($r) = @_;
+    my ($r) = @_;
 
     local $_;
     my $uri = $r->uri;
@@ -318,7 +304,7 @@ sub status_rgysubs {
         push @retval, "<h4>$handler:</h4>\n<p>\n";
         for (sort @{ $handlers{$handler} }) {
             my $full = join '::', $root, $handler, $_;
-            push @retval, qq(<a href="$uri?$full">$_</a>\n), "<br>";
+            push @retval, qq(<a href="$uri?$full">$_</a>\n), "<br />";
         }
         push @retval, "</p>\n";
     }
@@ -385,11 +371,11 @@ sub status_isa_tree {
 }
 
 sub status_data_dump {
-    my($r) = @_;
+    my ($r) = @_;
 
     return install_hint('Data::Dumper') unless has($r, "dumper");
 
-    my($name, $type) = (split "/", $r->uri)[-2,-1];
+    my ($name, $type) = (split "/", $r->uri)[-2,-1];
 
     no strict 'refs';
     my @retval = "<p>\nData Dump of $name $type\n</p>\n<pre>\n";
@@ -408,14 +394,14 @@ sub cv_file {
     $obj->can('FILEGV') ? $obj->FILEGV->SV->PV : $obj->FILE;
 }
 
-sub status_cv_dump { 
-    my($r) = @_;
+sub status_cv_dump {
+    my ($r) = @_;
     return [] unless has($r, "b");
 
     no strict 'refs';
-    my($name, $type) = (split "/", $r->uri)[-2,-1];
+    my ($name, $type) = (split "/", $r->uri)[-2,-1];
     # could be another child, which doesn't have this symbol table?
-    return unless *$name{CODE}; 
+    return unless *$name{CODE};
 
     my @retval = "<p>Subroutine info for <b>$name</b></p>\n<pre>\n";
     my $obj    = B::svref_2object(*$name{CODE});
@@ -423,7 +409,7 @@ sub status_cv_dump {
     my $stash  = $obj->GV->STASH->NAME;
     my $script = $r->location;
 
-    push @retval, "File: ", 
+    push @retval, "File: ",
         (-e $file ? qq(<a href="file:$file">$file</a>) : $file), "\n";
 
     my $cv    = $obj->GV->CV;
@@ -434,8 +420,8 @@ sub status_cv_dump {
     push @retval, "Prototype: ", $proto || "none", "\n";
     push @retval, "XSUB: ",      $obj->XSUB ? "yes" : "no", "\n";
     push @retval, peek_link($r, $name, $type);
-    #push @retval, xref_link($r, $name);
     push @retval, b_graph_link($r, $name);
+    push @retval, xref_link($r, $name);
     push @retval, b_lexinfo_link($r, $name);
     push @retval, b_terse_link($r, $name);
     push @retval, b_terse_size_link($r, $name);
@@ -446,7 +432,7 @@ sub status_cv_dump {
 }
 
 sub b_lexinfo_link {
-    my($r, $name) = @_;
+    my ($r, $name) = @_;
 
     return unless has($r, "lexinfo");
 
@@ -461,23 +447,23 @@ sub noh_b_lexinfo {
     return unless has($r, "lexinfo");
 
     no strict 'refs';
-    my($name) = (split "/", $r->uri)[-1];
+    my ($name) = (split "/", $r->uri)[-1];
     $r->print("Lexical Info for $name\n\n");
     my $lexi = B::LexInfo->new;
     my $info = $lexi->cvlexinfo($name);
     $r->print(${ $lexi->dumper($info) });
 }
 
-my %b_terse_exp = ('slow' => 'syntax', 'exec' => 'execution');
+my %b_terse_exp = ('slow' => 'syntax', 'exec' => 'execution', basic => 'syntax');
 
 sub b_terse_link {
-    my($r, $name) = @_;
+    my ($r, $name) = @_;
 
     return unless has($r, "terse");
 
     my $script = $r->location;
     my @retval;
-    for (qw(exec slow)) {
+    for (qw(exec basic)) {
         my $exp = "$b_terse_exp{$_} order";
         push @retval,
             qq(\n<a href="$script/$_/$name?noh_b_terse">Syntax Tree Dump ($exp)</a>\n);
@@ -492,20 +478,21 @@ sub noh_b_terse {
     return unless has($r, "terse");
 
     no strict 'refs';
-    my($arg, $name) = (split "/", $r->uri)[-2,-1];
+    my ($arg, $name) = (split "/", $r->uri)[-2,-1];
     $r->print("Syntax Tree Dump ($b_terse_exp{$arg}) for $name\n\n");
 
     # XXX: blead perl dumps things to STDERR, though the same version
     # works fine with 1.27
     # B::Concise couldn't parse XS code before perl patch 24681 (perl 5.9.3)
-    eval { B::Terse::compile($arg, $name)->() };
+    # B::Terse is deprecated and just a wrapper around B::Concise now adays
+    eval { B::Concise::compile("-terse", "-$arg", $name)->() };
     if ($@) {
-        $r->print("B::Terse has failed: $@");
+        $r->print("B::Concise has failed: $@");
     }
 }
 
 sub b_terse_size_link {
-    my($r, $name) = @_;
+    my ($r, $name) = @_;
 
     return unless has($r, "tersesize");
 
@@ -526,7 +513,7 @@ sub noh_b_terse_size {
     return unless has($r, "tersesize");
 
     $r->print('<pre>');
-    my($arg, $name) = (split "/", $r->uri)[-2,-1];
+    my ($arg, $name) = (split "/", $r->uri)[-2,-1];
     my $uri = $r->location;
     my $link = qq{<a href="$uri/$name/CODE?cv_dump">$name</a>};
     $r->print("Syntax Tree Size ($b_terse_exp{$arg} order) for $link\n\n");
@@ -534,7 +521,7 @@ sub noh_b_terse_size {
 }
 
 sub b_package_size_link {
-    my($r, $name) = @_;
+    my ($r, $name) = @_;
 
     return unless has($r, "packagesize");
 
@@ -543,7 +530,7 @@ sub b_package_size_link {
 }
 
 sub noh_b_package_size {
-    my($r) = @_;
+    my ($r) = @_;
 
     $r->content_type("text/html");
     return unless has($r, "packagesize");
@@ -551,11 +538,13 @@ sub noh_b_package_size {
     $r->print('<pre>');
 
     no strict 'refs';
-    my($package) = (split "/", $r->uri)[-1];
+    my ($package) = (split "/", $r->uri)[-1];
     my $script = $r->location;
     $r->print("Memory Usage for package $package\n\n");
-    my($subs, $opcount, $opsize) = B::TerseSize::package_size($package);
-    $r->print("Totals: $opsize bytes | $opcount OPs\n\n");
+    my ($subs, $opcount, $opsize) = B::TerseSize::package_size($package);
+    my $Kb = sprintf "%.2f", $opsize / 1024;
+    my $Mb = sprintf "%.2f", $Kb / 1000;
+    $r->print("Totals: $opsize bytes, $Kb Kb, $Mb Mb | $opcount OPs\n\n");
 
     my $nlen = 0;
     my @keys = map {
@@ -563,7 +552,8 @@ sub noh_b_package_size {
         $_;
     } (sort { $subs->{$b}->{size} <=> $subs->{$a}->{size} } keys %$subs);
 
-    my $clen = length $subs->{$keys[0]}->{count};
+    my $clen = $subs->{$keys[0]}->{count} ?
+        length $subs->{$keys[0]}->{count} : 0;
     my $slen = length $subs->{$keys[0]}->{size};
 
     for my $name (@keys) {
@@ -573,11 +563,11 @@ sub noh_b_package_size {
         }
         elsif ($name =~ /^\*(\w+)\{(\w+)\}/) {
             my $link = qq(<a href="$script/$package\::$1/$2?data_dump">);
-            $r->printf("$link%-${nlen}s</a> %${slen}d bytes\n", 
+            $r->printf("$link%-${nlen}s</a> %${slen}d bytes\n",
                        $name, $stats->{size});
         }
         else {
-            my $link = 
+            my $link =
                 qq(<a href="$script/slow/$package\::$name?noh_b_terse_size">);
             $r->printf("$link%-${nlen}s</a> %${slen}d bytes | %${clen}d OPs\n",
                        $name, $stats->{size}, $stats->{count});
@@ -586,7 +576,7 @@ sub noh_b_package_size {
 }
 
 sub b_deparse_link {
-    my($r, $name) = @_;
+    my ($r, $name) = @_;
 
     return unless has($r, "deparse");
 
@@ -602,14 +592,14 @@ sub noh_b_deparse {
 
     my $name = (split "/", $r->uri)[-1];
     $r->print("Deparse of $name\n\n");
-    my $deparse = B::Deparse->new(split /\s+/, 
+    my $deparse = B::Deparse->new(split /\s+/,
                                   $r->dir_config('StatusDeparseOptions')||"");
     my $body = $deparse->coderef2text(\&{$name});
     $r->print("sub $name $body");
 }
 
 sub b_fathom_link {
-    my($r, $name) = @_;
+    my ($r, $name) = @_;
 
     return unless has($r, "fathom");
 
@@ -625,13 +615,13 @@ sub noh_b_fathom {
 
     my $name = (split "/", $r->uri)[-1];
     $r->print("Fathom Score of $name\n\n");
-    my $fathom = B::Fathom->new(split /\s+/, 
+    my $fathom = B::Fathom->new(split /\s+/,
                                 $r->dir_config('StatusFathomOptions')||"");
     $r->print($fathom->fathom(\&{$name}));
 }
 
 sub peek_link {
-    my($r, $name, $type) = @_;
+    my ($r, $name, $type) = @_;
 
     return unless has($r, "peek");
 
@@ -646,14 +636,14 @@ sub noh_peek {
     return unless has($r, "peek");
 
     no strict 'refs';
-    my($name, $type) = (split "/", $r->uri)[-2,-1];
+    my ($name, $type) = (split "/", $r->uri)[-2,-1];
     $type =~ s/^FUNCTION$/CODE/;
     $r->print("Peek Dump of $name $type\n\n");
-    Apache2::Peek::Dump(*{$name}{$type});
+    Apache::Peek::Dump(*{$name}{$type});
 }
 
 sub xref_link {
-    my($r, $name) = @_;
+    my ($r, $name) = @_;
 
     return unless has($r, "xref");
 
@@ -680,7 +670,7 @@ if ($Apache2::Status::BGraphCache) {
 }
 
 sub b_graph_link {
-    my($r, $name) = @_;
+    my ($r, $name) = @_;
 
     return unless has($r, "graph");
 
@@ -706,9 +696,15 @@ sub noh_b_graph {
     my $file = "$dir/$thing.$$.gif";
 
     unless (-e $file) {
-        tie *STDOUT, "B::Graph", $r, $file;
-        B::Graph::compile("-$type", $thing)->();
-        (tied *STDOUT)->{graph}->close;
+        my $rv = tie *STDOUT, "B::Graph", $r, $file;
+        unless ($rv) {
+            $r->content_type("text/plain");
+            $r->print("dot not found\n");
+        }
+        else {
+            B::Graph::compile("-$type", $thing)->();
+            (tied *STDOUT)->{graph}->close;
+        }
     }
 
     if (-s $file) {
@@ -730,7 +726,7 @@ sub noh_b_graph {
 }
 
 sub B::Graph::TIEHANDLE {
-    my($class, $r, $file) = @_;
+    my ($class, $r, $file) = @_;
 
     if ($file =~ /^([^<>|;]+)$/) {
         $file = $1;
@@ -744,13 +740,17 @@ sub B::Graph::TIEHANDLE {
 
     require IO::File;
     my $pipe = IO::File->new("|$dot -Tgif -o $file");
-    $pipe or die "can't open pipe to dot $!";
-    $pipe->autoflush(1);
+    $pipe && $pipe->autoflush(1);
 
-    return bless {
-                  graph => $pipe,
-                  r     => $r,
-    }, $class;
+    if ($pipe) {
+        return bless {
+            graph => $pipe,
+            r     => $r,
+        }, $class;
+    }
+    else {
+        return;
+    }
 }
 
 sub B::Graph::PRINT {
@@ -762,7 +762,7 @@ sub B::Graph::PRINT {
 my %can_dump = map {$_,1} qw(scalars arrays hashes);
 
 sub as_HTML {
-    my($self, $package, $r) = @_;
+    my ($self, $package, $r) = @_;
 
     my @m = qw(<table>);
     my $uri = $r->uri;
@@ -772,7 +772,7 @@ sub as_HTML {
 
     my @methods = sort keys %{$self->{'AUTOLOAD'}};
 
-    if ($is_main) { 
+    if ($is_main) {
         @methods = grep { $_ ne "packages" } @methods;
         unshift @methods, "packages";
     }
@@ -783,7 +783,7 @@ sub as_HTML {
         my @line = ();
 
         for (sort $self->_partdump(uc $type)) {
-            s/([\000-\037\177])/ '^' . pack('c', ord($1) ^ 64)/eg; 
+            s/([\000-\037\177])/ '^' . pack('c', ord($1) ^ 64)/eg;
 
             if ($type eq "scalars") {
                 no strict 'refs';
