@@ -1,8 +1,9 @@
-# Copyright 2000-2005 The Apache Software Foundation
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
+# Licensed to the Apache Software Foundation (ASF) under one or more
+# contributor license agreements.  See the NOTICE file distributed with
+# this work for additional information regarding copyright ownership.
+# The ASF licenses this file to You under the Apache License, Version 2.0
+# (the "License"); you may not use this file except in compliance with
+# the License.  You may obtain a copy of the License at
 #
 #     http://www.apache.org/licenses/LICENSE-2.0
 #
@@ -27,7 +28,7 @@ use constant UNKNOWN_FATAL => 2;
 use File::Spec;
 
 sub init {
-    my($self, $build) = @_;
+    my ($self, $build) = @_;
 
     #@ARGV should override what's in .makepl_args.mod_perl2
     #but @ARGV might also override the default MP_OPTS_FILE
@@ -68,7 +69,7 @@ sub init {
 }
 
 sub parse {
-    my($self, $lines, $opts) = @_;
+    my ($self, $lines, $opts) = @_;
 
     $opts = VERBOSE|UNKNOWN_FATAL unless defined $opts;
     my $table = table();
@@ -100,7 +101,7 @@ sub parse {
         }
 
         if (/^MP_/) {
-            my($key, $val) = split $param_qr, $_, 2;
+            my ($key, $val) = split $param_qr, $_, 2;
             $val ||= "" unless defined $val && $val eq '0';
             $continue = $val =~ s/\\$// ? $key : "";
 
@@ -121,6 +122,11 @@ sub parse {
                     require Win32;
                     $val = Win32::GetShortPathName($val);
                 }
+
+                if (!$val || !-d $val) {
+                    error "MP_AP_PREFIX must point to a valid directory.";
+                    die "\n";
+                }
             }
 
             if ($table->{$key}->{append}){
@@ -185,7 +191,7 @@ sub usage {
 }
 
 sub parse_table {
-    my($fh) = @_;
+    my ($fh) = @_;
     my %table;
     local $_;
 
@@ -194,7 +200,7 @@ sub parse_table {
         s/^\s+//; s/\s+$//;
         next if /^\#/ || /^$/;
         last if /^__END__/;
-        my($key, $append, $val) = split /\s+/, $_, 3;
+        my ($key, $append, $val) = split /\s+/, $_, 3;
         $table{'MP_' . $key} = { append => $append, val => $val };
     }
 
