@@ -1,8 +1,9 @@
-/* Copyright 2001-2005 The Apache Software Foundation
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+/* Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -32,7 +33,7 @@ MP_INLINE void modperl_io_handle_tie(pTHX_ GV *handle,
 
     SvREFCNT_dec(obj); /* since sv_magic did SvREFCNT_inc */
 
-    MP_TRACE_r(MP_FUNC, "tie *%s(0x%lx) => %s, REFCNT=%d\n",
+    MP_TRACE_r(MP_FUNC, "tie *%s(0x%lx) => %s, REFCNT=%d",
                GvNAME(handle), (unsigned long)handle, classname,
                SvREFCNT(TIEHANDLE_SV(handle)));
 }
@@ -79,12 +80,12 @@ MP_INLINE int modperl_io_handle_tied(pTHX_ GV *handle, char *classname)
     SV *sv = TIEHANDLE_SV(handle);
 
     if (SvMAGICAL(sv) && (mg = mg_find(sv, PERL_MAGIC_tiedscalar))) {
-	char *package = HvNAME(SvSTASH((SV*)SvRV(mg->mg_obj)));
+        char *package = HvNAME(SvSTASH((SV*)SvRV(mg->mg_obj)));
 
-	if (!strEQ(package, classname)) {
-	    MP_TRACE_r(MP_FUNC, "%s tied to %s\n", GvNAME(handle), package);
-	    return TRUE;
-	}
+        if (!strEQ(package, classname)) {
+            MP_TRACE_r(MP_FUNC, "%s tied to %s", GvNAME(handle), package);
+            return TRUE;
+        }
     }
 
     return FALSE;
@@ -94,7 +95,7 @@ MP_INLINE void modperl_io_handle_untie(pTHX_ GV *handle)
 {
 #ifdef MP_TRACE
     if (mg_find(TIEHANDLE_SV(handle), PERL_MAGIC_tiedscalar)) {
-        MP_TRACE_r(MP_FUNC, "untie *%s(0x%lx), REFCNT=%d\n",
+        MP_TRACE_r(MP_FUNC, "untie *%s(0x%lx), REFCNT=%d",
                    GvNAME(handle), (unsigned long)handle,
                    SvREFCNT(TIEHANDLE_SV(handle)));
     }
@@ -121,26 +122,26 @@ MP_INLINE GV *modperl_io_perlio_override_stdin(pTHX_ request_rec *r)
                                  TRUE, SVt_PVIO);
 
         /* open my $oldout, "<&STDIN" or die "Can't dup STDIN: $!"; */
-        status = Perl_do_open(aTHX_ handle_save, "<&STDIN", 7, FALSE,
-                              O_RDONLY, 0, Nullfp);
+        status = do_open(handle_save, "<&STDIN", 7, FALSE,
+                         O_RDONLY, 0, Nullfp);
         if (status == 0) {
-            Perl_croak(aTHX_ "Failed to dup STDIN: %_", get_sv("!", TRUE));
+            Perl_croak(aTHX_ "Failed to dup STDIN: %" SVf, get_sv("!", TRUE));
         }
 
         /* similar to PerlIO::scalar, the PerlIO::Apache layer doesn't
          * have file descriptors, so STDIN must be closed before it can
          * be reopened */
-        Perl_do_close(aTHX_ handle, TRUE);
+        do_close(handle, TRUE);
     }
 
     sv_setref_pv(sv, "Apache2::RequestRec", (void*)r);
-    status = Perl_do_open9(aTHX_ handle, "<:Apache2", 9, FALSE, O_RDONLY,
-                           0, Nullfp, sv, 1);
+    status = do_open9(handle, "<:Apache2", 9, FALSE, O_RDONLY,
+                      0, Nullfp, sv, 1);
     if (status == 0) {
-        Perl_croak(aTHX_ "Failed to open STDIN: %_", get_sv("!", TRUE));
+        Perl_croak(aTHX_ "Failed to open STDIN: %" SVf, get_sv("!", TRUE));
     }
 
-    MP_TRACE_o(MP_FUNC, "end\n");
+    MP_TRACE_o(MP_FUNC, "end");
 
     return handle_save;
 }
@@ -164,26 +165,26 @@ MP_INLINE GV *modperl_io_perlio_override_stdout(pTHX_ request_rec *r)
                                  TRUE, SVt_PVIO);
 
         /* open my $oldout, ">&STDOUT" or die "Can't dup STDOUT: $!"; */
-        status = Perl_do_open(aTHX_ handle_save, ">&STDOUT", 8, FALSE,
-                              O_WRONLY, 0, Nullfp);
+        status = do_open(handle_save, ">&STDOUT", 8, FALSE,
+                         O_WRONLY, 0, Nullfp);
         if (status == 0) {
-            Perl_croak(aTHX_ "Failed to dup STDOUT: %_", get_sv("!", TRUE));
+            Perl_croak(aTHX_ "Failed to dup STDOUT: %" SVf, get_sv("!", TRUE));
         }
 
         /* similar to PerlIO::scalar, the PerlIO::Apache layer doesn't
          * have file descriptors, so STDOUT must be closed before it can
          * be reopened */
-        Perl_do_close(aTHX_ handle, TRUE);
+        do_close(handle, TRUE);
     }
 
     sv_setref_pv(sv, "Apache2::RequestRec", (void*)r);
-    status = Perl_do_open9(aTHX_ handle, ">:Apache2", 9, FALSE, O_WRONLY,
-                           0, Nullfp, sv, 1);
+    status = do_open9(handle, ">:Apache2", 9, FALSE, O_WRONLY,
+                      0, Nullfp, sv, 1);
     if (status == 0) {
-        Perl_croak(aTHX_ "Failed to open STDOUT: %_", get_sv("!", TRUE));
+        Perl_croak(aTHX_ "Failed to open STDOUT: %" SVf, get_sv("!", TRUE));
     }
 
-    MP_TRACE_o(MP_FUNC, "end\n");
+    MP_TRACE_o(MP_FUNC, "end");
 
     /* XXX: shouldn't we preserve the value STDOUT had before it was
      * overridden? */
@@ -200,7 +201,7 @@ MP_INLINE void modperl_io_perlio_restore_stdin(pTHX_ GV *handle)
     MP_TRACE_o(MP_FUNC, "start");
 
     /* close the overriding filehandle */
-    Perl_do_close(aTHX_ handle_orig, FALSE);
+    do_close(handle_orig, FALSE);
 
     /*
      * open STDIN, "<&STDIN_SAVED" or die "Can't dup STDIN_SAVED: $!";
@@ -211,25 +212,25 @@ MP_INLINE void modperl_io_perlio_restore_stdin(pTHX_ GV *handle)
 
         MP_TRACE_o(MP_FUNC, "restoring STDIN");
 
-        if (Perl_do_open9(aTHX_ handle_orig, "<&", 2, FALSE,
-                          O_RDONLY, 0, Nullfp, (SV*)handle, 1) == 0) {
+        if (do_open9(handle_orig, "<&", 2, FALSE,
+                     O_RDONLY, 0, Nullfp, (SV*)handle, 1) == 0) {
             err = get_sv("!", TRUE);
         }
 
-        Perl_do_close(aTHX_ handle, FALSE);
-        (void)hv_delete(gv_stashpv("Apache2::RequestIO", TRUE), 
+        do_close(handle, FALSE);
+        (void)hv_delete(gv_stashpv("Apache2::RequestIO", TRUE),
                         GvNAME(handle), GvNAMELEN(handle), G_DISCARD);
 
         if (err != Nullsv) {
-            Perl_croak(aTHX_ "Failed to restore STDIN: %_", err);
+            Perl_croak(aTHX_ "Failed to restore STDIN: %" SVf, err);
         }
     }
 
-    MP_TRACE_o(MP_FUNC, "end\n");
+    MP_TRACE_o(MP_FUNC, "end");
 }
 
 MP_INLINE void modperl_io_perlio_restore_stdout(pTHX_ GV *handle)
-{ 
+{
     GV *handle_orig = gv_fetchpv("STDOUT", FALSE, SVt_PVIO);
 
     MP_TRACE_o(MP_FUNC, "start");
@@ -243,11 +244,11 @@ MP_INLINE void modperl_io_perlio_restore_stdout(pTHX_ GV *handle)
      */
     if (GvIOn(handle_orig) && IoOFP(GvIOn(handle_orig)) &&
         (PerlIO_flush(IoOFP(GvIOn(handle_orig))) == -1)) {
-        Perl_croak(aTHX_ "Failed to flush STDOUT: %_", get_sv("!", TRUE));
+        Perl_croak(aTHX_ "Failed to flush STDOUT: %" SVf, get_sv("!", TRUE));
     }
 
     /* close the overriding filehandle */
-    Perl_do_close(aTHX_ handle_orig, FALSE);
+    do_close(handle_orig, FALSE);
 
     /*
      * open STDOUT, ">&STDOUT_SAVED" or die "Can't dup STDOUT_SAVED: $!";
@@ -258,19 +259,19 @@ MP_INLINE void modperl_io_perlio_restore_stdout(pTHX_ GV *handle)
 
         MP_TRACE_o(MP_FUNC, "restoring STDOUT");
 
-        if (Perl_do_open9(aTHX_ handle_orig, ">&", 2, FALSE,
-                          O_WRONLY, 0, Nullfp, (SV*)handle, 1) == 0) {
+        if (do_open9(handle_orig, ">&", 2, FALSE,
+                     O_WRONLY, 0, Nullfp, (SV*)handle, 1) == 0) {
             err = get_sv("!", TRUE);
         }
 
-        Perl_do_close(aTHX_ handle, FALSE);
-        (void)hv_delete(gv_stashpv("Apache2::RequestIO", TRUE), 
+        do_close(handle, FALSE);
+        (void)hv_delete(gv_stashpv("Apache2::RequestIO", TRUE),
                         GvNAME(handle), GvNAMELEN(handle), G_DISCARD);
 
         if (err != Nullsv) {
-            Perl_croak(aTHX_ "Failed to restore STDOUT: %_", err);
+            Perl_croak(aTHX_ "Failed to restore STDOUT: %" SVf, err);
         }
     }
 
-    MP_TRACE_o(MP_FUNC, "end\n");
+    MP_TRACE_o(MP_FUNC, "end");
 }
