@@ -17,10 +17,12 @@ sub handler {
 
     $r->content_type('text/plain');
 
-    my($code, $string) = split /=/, $r->args || '';
+    my ($code, $string) = split /=/, $r->args || '';
 
     if ($string) {
-        $r->status(200); # status_line should override status
+        # status_line must be valid and match status
+        # or it is 'zapped' by httpd as of 2.2.1
+        $r->status($code);
         $r->status_line("$code $string");
     }
     else {
