@@ -1,16 +1,18 @@
 package TestAPR::socket;
 
+# more tests in t/protocol/TestProtocol/echo_*.pm
+
 use strict;
 use warnings FATAL => 'all';
 
 use Apache::Test;
 use Apache::TestUtil;
 
-use Apache::RequestRec ();
-use Apache::Connection ();
+use Apache2::RequestRec ();
+use Apache2::Connection ();
 use APR::Socket ();
 
-use Apache::Const -compile => 'OK';
+use Apache2::Const -compile => 'OK';
 use APR::Const -compile => 'EMISMATCH';
 
 sub handler {
@@ -25,7 +27,6 @@ sub handler {
 
     ok $socket;
 
-
     # in microseconds
     my $orig_val = $socket->timeout_get();
     t_debug "orig timeout was: $orig_val";
@@ -33,13 +34,13 @@ sub handler {
 
     my $new_val = 30_000_000; # 30 secs
     $socket->timeout_set($new_val);
-    ok t_cmp($new_val, $socket->timeout_get(), "timeout_get()");
+    ok t_cmp($socket->timeout_get(), $new_val, "timeout_get()");
 
     # reset the timeout
     $socket->timeout_set($orig_val);
-    ok t_cmp($orig_val, $socket->timeout_get(), "timeout_get()");
+    ok t_cmp($socket->timeout_get(), $orig_val, "timeout_get()");
 
-    Apache::OK;
+    Apache2::Const::OK;
 }
 
 1;
