@@ -1,8 +1,9 @@
-/* Copyright 2001-2005 The Apache Software Foundation
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+/* Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  *
  *     http://www.apache.org/licenses/LICENSE-2.0
  *
@@ -43,7 +44,7 @@ apr_size_t mpxs_apr_socket_send(pTHX_ apr_socket_t *socket,
         if (buf_len < SvIV(sv_len)) {
             Perl_croak(aTHX_ "the 3rd arg (%d) is bigger than the "
                        "length (%d) of the 2nd argument",
-                       SvIV(sv_len), buf_len);
+                       (int)SvIV(sv_len), buf_len);
         }
         buf_len = SvIV(sv_len);
     }
@@ -58,7 +59,7 @@ static MP_INLINE
 apr_interval_time_t mpxs_apr_socket_timeout_get(pTHX_ I32 items,
                                                 SV **MARK, SV **SP)
 {
-    apr_interval_time_t	t;
+    apr_interval_time_t t;
     APR__Socket APR__Socket;
 
     /* this also magically assings to APR_Socket ;-) */
